@@ -2,6 +2,7 @@
 ## package 'secr'
 ## list.secr.fit.R
 ## 2024-02-19 supercedes par.secr.fit
+## 2024-07-11 robust to partial failure
 ################################################################################
 
 ## keeping it simple
@@ -14,5 +15,10 @@ list.secr.fit <- function (..., constant = list(), prefix = "fit", names = NULL)
         warning ("number of names does not equal number of fits")
         names <- defaultnames
     }
-    secrlist(fits, names = names)
+    ok <- sapply(fits, inherits, 'secr')
+    if (any(!ok)) {
+        if (all(!ok)) stop ("no valid fits") 
+        else warning (sum(!ok), " fits failed and were dropped")
+    }
+    secrlist(fits[ok], names = names[ok])
 }
