@@ -13,6 +13,8 @@
 ## 2023-04-14 trim.secrlist
 ## 2023-05-30 shift.mask updates boundingbox; explicitly call secr::shift 
 ## 2023-08-19 as.popn()  ppp > popn
+## 2024-07-29 print.secrdata, print.secrlist moved from sim.secr.R
+
 ###############################################################################
 
 # Generic methods for extracting attributes etc
@@ -2257,10 +2259,25 @@ coef.secrlist <- function (object, alpha=0.05, ...) {
 }
 ############################################################################################
 
+print.secrdata <- function(x,...) {
+    ## suggestion of Rolf Turner 19 Jan 2009 for printing without attributes
+    attributes(x) <- NULL
+    print(x)
+}
+############################################################################################
+
+print.secrlist <- function(x,...) {
+    ## suggestion of Rolf Turner 19 Jan 2009 for printing without attributes
+    attributes(x) <- NULL
+    print(x)
+}
+############################################################################################
+
 detectpar.default <- function(object, ...) {
     stop ("only for secr models")
 }
 ## byclass option 2013-11-09
+## pmix 2024-08-05
 detectpar.secr <- function(object, ..., byclass = FALSE) {
     extractpar <- function (temp) {
         if (!is.data.frame(temp))   ## assume list
@@ -2297,6 +2314,7 @@ detectpar.secr <- function(object, ..., byclass = FALSE) {
                 else if (object$detectfn %in% 14:19) 'lambda0'
                 else stop ('invalid combination of param %in% c(3,5) and detectfn')
             }
+            if (object$details$nmix > 1) pnames <- c(pnames, 'pmix')
             temp <- temp[pnames]
             if ((object$detectfn > 9) & (object$detectfn <14))
                 temp <- c(temp, list(cutval = object$details$cutval))
