@@ -31,6 +31,7 @@
 ## 2023-05-21 4.6.0
 ## 2023-09-17 im2mask converts spatstat im object
 ## 2024-03-19 rlnormCV
+## 2024-07-31 addzeroCH tweaked to allow zero-row covariate df + drop = FALSE
 ################################################################################
 
 # Global variables in namespace
@@ -1758,7 +1759,7 @@ addzerodf <- function (df, oldCH, sess) {
 
 ## including pre-marked animals never sighted
 ## cov is optional dataframe of covariates
-addzeroCH <- function (CH, nzero, cov = NULL) {
+addzeroCH <- function (CH, nzero, cov = NULL, prefix = 'Z') {
     if (nzero == 0)
         return(CH)
     else {
@@ -1766,17 +1767,17 @@ addzeroCH <- function (CH, nzero, cov = NULL) {
         chdim <- dim(CH)
         chdim[1] <- nzero
         extra <- array(0, dim=chdim)
-        dimnames(extra) <- c(list(paste('Z', 1:nzero, sep='')), dimnames(CH)[2:3])
+        dimnames(extra) <- c(list(paste(prefix, 1:nzero, sep='')), dimnames(CH)[2:3])
         CH2 <- abind(CH, extra, along = 1)
         class(CH2) <- 'capthist'
         traps(CH2) <- traps(CH)
         xy(CH2) <- xy(CH)  ## order is not affected by adding zero histories
-        if (!is.null(covariates(CH)) & (nrow(CH)>0)) {
+        if (!is.null(covariates(CH)) && nrow(covariates(CH))>0 && (nrow(CH)>0)) {
             if (is.null(cov)) {
-                cov <- covariates(CH)[rep(1,nzero),]
+                cov <- covariates(CH)[rep(1,nzero),,drop = FALSE]
                 cov[,] <- NA   ## covariates are unknown
             }
-            covariates(CH2) <- rbind(covariates(CH), cov[1:nzero,])
+            covariates(CH2) <- rbind(covariates(CH), cov[1:nzero,,drop = FALSE])
         }
         ## ... and other essential attributes?
         CH2
